==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AProtectedModifier.h <==
// public final class soot.jimple.parser.node.AProtectedModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 11a81101c5252fc6 soot_jimple_parser_node_AProtectedModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AProtectedModifier_H_
#define _JC_soot_jimple_parser_node_AProtectedModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TProtected$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$sub_refs	_jc_soot_jimple_parser_node_AProtectedModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AProtectedModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$refs	_jc_soot_jimple_parser_node_AProtectedModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$nonrefs	_jc_soot_jimple_parser_node_AProtectedModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$object	_jc_soot_jimple_parser_node_AProtectedModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AProtectedModifier$vmethods	_jc_soot_jimple_parser_node_AProtectedModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AProtectedModifier$vtable	_jc_soot_jimple_parser_node_AProtectedModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AProtectedModifier$vtype	_jc_soot_jimple_parser_node_AProtectedModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *);
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$_init$c5f476adcbe26fd0(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_TProtected$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AProtectedModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *);
extern struct _jc_soot_jimple_parser_node_TProtected$object *_jc_soot_jimple_parser_node_AProtectedModifier$method$getProtected$44b6b20864310a8f(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *);
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$setProtected$6afad0a13fb8c1ad(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_TProtected$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AProtectedModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$getProtected$44b6b20864310a8f;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$setProtected$6afad0a13fb8c1ad;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AProtectedModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *);
	struct _jc_soot_jimple_parser_node_TProtected$object	*(*getProtected$44b6b20864310a8f)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setProtected$6afad0a13fb8c1ad)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_TProtected$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AProtectedModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AProtectedModifier$vmethods	soot_jimple_parser_node_AProtectedModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AProtectedModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AProtectedModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AProtectedModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TProtected$object	*__5fprotected__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AProtectedModifier$refs {
    _jc_soot_jimple_parser_node_AProtectedModifier$sub_refs	soot_jimple_parser_node_AProtectedModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AProtectedModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AProtectedModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AProtectedModifier$sub_nonrefs	soot_jimple_parser_node_AProtectedModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AProtectedModifier$object {
	_jc_soot_jimple_parser_node_AProtectedModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AProtectedModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AProtectedModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AProtectedModifier$vtype _jc_soot_jimple_parser_node_AProtectedModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AProtectedModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AProtectedModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AProtectedModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AProtectedModifier.h <==
// public final class soot.jimple.parser.node.AProtectedModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 11a81101c5252fc6 soot_jimple_parser_node_AProtectedModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AProtectedModifier_H_
#define _JC_soot_jimple_parser_node_AProtectedModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TProtected$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$sub_refs	_jc_soot_jimple_parser_node_AProtectedModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AProtectedModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$refs	_jc_soot_jimple_parser_node_AProtectedModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$nonrefs	_jc_soot_jimple_parser_node_AProtectedModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AProtectedModifier$object	_jc_soot_jimple_parser_node_AProtectedModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AProtectedModifier$vmethods	_jc_soot_jimple_parser_node_AProtectedModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AProtectedModifier$vtable	_jc_soot_jimple_parser_node_AProtectedModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AProtectedModifier$vtype	_jc_soot_jimple_parser_node_AProtectedModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$_init$c5f476adcbe26fd0(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_TProtected$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AProtectedModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TProtected$object *_jc_soot_jimple_parser_node_AProtectedModifier$method$getProtected$44b6b20864310a8f(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AProtectedModifier$method$setProtected$6afad0a13fb8c1ad(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_TProtected$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AProtectedModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$getProtected$44b6b20864310a8f;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$setProtected$6afad0a13fb8c1ad;
extern _jc_method _jc_soot_jimple_parser_node_AProtectedModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AProtectedModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TProtected$object	*(*getProtected$44b6b20864310a8f)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setProtected$6afad0a13fb8c1ad)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *, struct _jc_soot_jimple_parser_node_TProtected$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AProtectedModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AProtectedModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AProtectedModifier$vmethods	soot_jimple_parser_node_AProtectedModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AProtectedModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AProtectedModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AProtectedModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TProtected$object	*__5fprotected__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AProtectedModifier$refs {
    _jc_soot_jimple_parser_node_AProtectedModifier$sub_refs	soot_jimple_parser_node_AProtectedModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AProtectedModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AProtectedModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AProtectedModifier$sub_nonrefs	soot_jimple_parser_node_AProtectedModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AProtectedModifier$object {
	_jc_soot_jimple_parser_node_AProtectedModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AProtectedModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AProtectedModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AProtectedModifier$vtype _jc_soot_jimple_parser_node_AProtectedModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AProtectedModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AProtectedModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AProtectedModifier_H_ */
